@@ -1,7 +1,7 @@
 """Messaging Framework for Python"""
 from __future__ import absolute_import
 
-VERSION = (2, 5, 4)
+VERSION = (2, 5, 5)
 __version__ = '.'.join(map(str, VERSION[0:3])) + ''.join(VERSION[3:])
 __author__ = 'Ask Solem'
 __contact__ = 'ask@celeryproject.org'
@@ -16,8 +16,8 @@ import sys
 if sys.version_info < (2, 5):  # pragma: no cover
     if sys.version_info >= (2, 4):
         raise Exception(
-                'Python 2.4 is not supported by this version. '
-                'Please use Kombu versions 1.x.')
+            'Python 2.4 is not supported by this version. '
+            'Please use Kombu versions 1.x.')
     else:
         raise Exception('Kombu requires Python versions 2.5 or later.')
 
@@ -28,7 +28,7 @@ if STATICA_HACK:  # pragma: no cover
     # pylint, etc.) into knowing the types of these symbols, and what
     # they contain.
     from kombu.connection import Connection, BrokerConnection   # noqa
-    from kombu.entitiy import Exchange, Queue, binding          # noqa
+    from kombu.entity import Exchange, Queue, binding           # noqa
     from kombu.messaging import Consumer, Producer              # noqa
     from kombu.pools import connections, producers              # noqa
     from kombu.utils.url import parse_url                       # noqa
