@@ -93,12 +93,12 @@ class Table(Domain):
             if item:
                 return item
 
-    def select(self, query='', next_token=None, consistent_read=True,
-            max_items=None):
+    def select(self, query='', next_token=None,
+               consistent_read=True, max_items=None):
         """Uses `consistent_read` by default."""
         query = """SELECT * FROM `%s` %s""" % (self.name, query)
         return Domain.select(self, query, next_token,
-                                   consistent_read, max_items)
+                             consistent_read, max_items)
 
     def _try_first(self, query='', **kwargs):
         for c in (False, True):
@@ -122,6 +122,8 @@ class Channel(virtual.Channel):
 
     default_region = 'us-east-1'
     default_visibility_timeout = 1800  # 30 minutes.
+    # 20 seconds is the max value currently supported by SQS.
+    default_wait_time_seconds = 20
     domain_format = 'kombu%(vhost)s'
     _sdb = None
     _sqs = None
@@ -164,7 +166,8 @@ class Channel(virtual.Channel):
             return self._queue_cache[queue]
         except KeyError:
             q = self._queue_cache[queue] = self.sqs.create_queue(
-                    queue, self.visibility_timeout)
+                queue, self.visibility_timeout,
+            )
             return q
 
     def _queue_bind(self, *args):
@@ -184,7 +187,7 @@ class Channel(virtual.Channel):
         """
         if self.supports_fanout:
             return [(r['routing_key'], r['pattern'], r['queue'])
-                        for r in self.table.routes_for(exchange)]
+                    for r in self.table.routes_for(exchange)]
         return super(Channel, self).get_table(exchange)
 
     def get_exchanges(self):
@@ -226,7 +229,7 @@ class Channel(virtual.Channel):
     def _get(self, queue):
         """Try to retrieve a single message off ``queue``."""
         q = self._new_queue(queue)
-        rs = q.get_messages(1)
+        rs = q.get_messages(1, wait_time_seconds=self.wait_time_seconds)
         if rs:
             m = rs[0]
             payload = loads(rs[0].get_body())
@@ -238,6 +241,13 @@ class Channel(virtual.Channel):
             return payload
         raise Empty()
 
+    def _restore(self, message,
+                 unwanted_delivery_info=('sqs_message', 'sqs_queue')):
+        for unwanted_key in unwanted_delivery_info:
+            # Remove objects that aren't JSON serializable (Issue #1108).
+            message.delivery_info.pop(unwanted_key, None)
+        return super(Channel, self)._restore(message)
+
     def basic_ack(self, delivery_tag):
         delivery_info = self.qos.get(delivery_tag).delivery_info
         try:
@@ -306,10 +316,10 @@ class Channel(virtual.Channel):
 
     @property
     def table(self):
-        name = self.entity_name(self.domain_format % {
-                                    'vhost': self.conninfo.virtual_host})
-        d = self.sdb.get_object('CreateDomain', {'DomainName': name},
-                                self.Table)
+        name = self.entity_name(
+            self.domain_format % {'vhost': self.conninfo.virtual_host})
+        d = self.sdb.get_object(
+            'CreateDomain', {'DomainName': name}, self.Table)
         d.name = name
         return d
 
@@ -338,11 +348,17 @@ class Channel(virtual.Channel):
     def region(self):
         return self.transport_options.get('region') or self.default_region
 
+    @cached_property
+    def wait_time_seconds(self):
+        return (self.transport_options.get('wait_time_seconds') or
+                self.default_wait_time_seconds)
+
 
 class Transport(virtual.Transport):
     Channel = Channel
 
-    polling_interval = 1
+    polling_interval = 0
+    wait_time_seconds = 20
     default_port = None
     connection_errors = (StdConnectionError, exception.SQSError, socket.error)
     channel_errors = (exception.SQSDecodeError, StdChannelError)
