@@ -71,24 +71,27 @@ class MutexHeld(Exception):
 @contextmanager
 def Mutex(client, name, expire):
     lock_id = uuid()
-    if client.setnx(name, lock_id):
-        client.expire(name, expire)
-        yield
-    else:
-        if not client.ttl(name):
-            client.expire(name, expire)
-        raise MutexHeld()
-
-    pipe = client.pipeline(True)
+    i_won = client.setnx(name, lock_id)
     try:
-        pipe.watch(name)
-        if pipe.get(name) == lock_id:
-            pipe.multi()
-            pipe.delete(name)
-            pipe.execute()
-        pipe.unwatch()
-    except redis.WatchError:
-        pass
+        if i_won:
+            client.expire(name, expire)
+            yield
+        else:
+            if not client.ttl(name):
+                client.expire(name, expire)
+            raise MutexHeld()
+    finally:
+        if i_won:
+            pipe = client.pipeline(True)
+            try:
+                pipe.watch(name)
+                if pipe.get(name) == lock_id:
+                    pipe.multi()
+                    pipe.delete(name)
+                    pipe.execute()
+                pipe.unwatch()
+            except redis.WatchError:
+                pass
 
 
 class QoS(virtual.QoS):
@@ -104,7 +107,7 @@ class QoS(virtual.QoS):
         with self.pipe_or_acquire() as pipe:
             pipe.zadd(self.unacked_index_key, delivery_tag, time()) \
                 .hset(self.unacked_key, delivery_tag,
-                    dumps([message._raw, EX, RK])) \
+                      dumps([message._raw, EX, RK])) \
                 .execute()
             super(QoS, self).append(message, delivery_tag)
 
@@ -141,7 +144,7 @@ class QoS(virtual.QoS):
             ceil = time() - self.visibility_timeout
             try:
                 with Mutex(client, self.unacked_mutex_key,
-                                   self.unacked_mutex_expire):
+                           self.unacked_mutex_expire):
                     visible = client.zrevrangebyscore(
                         self.unacked_index_key, ceil, 0,
                         start=num and start, num=num, withscores=True)
@@ -152,8 +155,8 @@ class QoS(virtual.QoS):
 
     def restore_by_tag(self, tag, client=None):
         with self.channel.conn_or_acquire(client) as client:
-            p, _, _ = self._remove_from_indices(tag,
-                client.pipeline().hget(self.unacked_key, tag)).execute()
+            p, _, _ = self._remove_from_indices(
+                tag, client.pipeline().hget(self.unacked_key, tag)).execute()
             if p:
                 M, EX, RK = loads(p)
                 self.channel._do_restore_message(M, EX, RK, client)
@@ -319,15 +322,17 @@ class Channel(virtual.Channel):
     max_connections = 10
     _pool = None
 
-    from_transport_options = (virtual.Channel.from_transport_options
-                            + ('unacked_key',
-                               'unacked_index_key',
-                               'unacked_mutex_key',
-                               'unacked_mutex_expire',
-                               'visibility_timeout',
-                               'unacked_restore_limit',
-                               'max_connections',
-                               'priority_steps'))
+    from_transport_options = (
+        virtual.Channel.from_transport_options +
+        ('unacked_key',
+         'unacked_index_key',
+         'unacked_mutex_key',
+         'unacked_mutex_expire',
+         'visibility_timeout',
+         'unacked_restore_limit',
+         'max_connections',
+         'priority_steps'),
+    )
 
     def __init__(self, *args, **kwargs):
         super_ = super(Channel, self)
@@ -371,15 +376,15 @@ class Channel(virtual.Channel):
                     client.lpush(queue, dumps(payload))
             except Exception:
                 logger.critical('Could not restore message: %r', payload,
-                        exc_info=True)
+                                exc_info=True)
 
     def _restore(self, message, payload=None):
         tag = message.delivery_tag
         with self.conn_or_acquire() as client:
             P, _ = client.pipeline() \
-                        .hget(self.unacked_key, tag) \
-                        .hdel(self.unacked_key, tag) \
-                    .execute()
+                .hget(self.unacked_key, tag) \
+                .hdel(self.unacked_key, tag) \
+                .execute()
             if P:
                 M, EX, RK = loads(P)
                 self._do_restore_message(M, EX, RK, client)
@@ -412,7 +417,7 @@ class Channel(virtual.Channel):
 
     def _subscribe(self):
         keys = [self._fanout_queues[queue]
-                    for queue in self.active_fanout_queues]
+                for queue in self.active_fanout_queues]
         if not keys:
             return
         c = self.subclient
@@ -450,7 +455,7 @@ class Channel(virtual.Channel):
         if not queues:
             return
         keys = [self._q_for_pri(queue, pri) for pri in PRIORITY_STEPS
-                        for queue in queues] + [timeout or 0]
+                for queue in queues] + [timeout or 0]
         self._in_poll = True
         self.client.connection.send_command('BRPOP', *keys)
 
@@ -559,8 +564,8 @@ class Channel(virtual.Channel):
             values = client.smembers(key)
             if not values:
                 raise InconsistencyError(
-                        'Queue list empty or key does not exist: %r' % (
-                            self.keyprefix_queue % exchange))
+                    'Queue list empty or key does not exist: %r' % (
+                        self.keyprefix_queue % exchange))
             return [tuple(val.split(self.sep)) for val in values]
 
     def _purge(self, queue):
@@ -652,8 +657,10 @@ class Channel(virtual.Channel):
         else:
             if self._in_poll:
                 client = self._create_client()
-                yield client
-                self.pool.release(client.connection)
+                try:
+                    yield client
+                finally:
+                    self.pool.release(client.connection)
             else:
                 yield self.client
 
@@ -712,7 +719,7 @@ class Channel(virtual.Channel):
     def active_queues(self):
         """Set of queues being consumed from (excluding fanout queues)."""
         return set(queue for queue in self._active_queues
-                            if queue not in self.active_fanout_queues)
+                   if queue not in self.active_fanout_queues)
 
 
 class Transport(virtual.Transport):
