@@ -4,10 +4,34 @@ kombu.utils.compat
 
 Helps compatibility with older Python versions.
 
-:copyright: (c) 2009 - 2012 by Ask Solem.
-:license: BSD, see LICENSE for more details.
-
 """
+############## py3k #########################################################
+import sys
+is_py3k = sys.version_info[0] == 3
+
+if is_py3k:                                 # pragma: no cover
+    from io import StringIO, BytesIO
+    from .encoding import bytes_to_str
+
+    class WhateverIO(StringIO):
+
+        def write(self, data):
+            StringIO.write(self, bytes_to_str(data))
+else:
+    from StringIO import StringIO           # noqa
+    BytesIO = WhateverIO = StringIO         # noqa
+
+############## __builtins__.next #############################################
+try:
+    next = next
+except NameError:
+    def next(it, *args):  # noqa
+        try:
+            return it.next()
+        except StopIteration:
+            if not args:
+                raise
+            return args[0]
 
 ############## collections.OrderedDict #######################################
 try:
